package com.ruoyi.ss.wifi.mapper;

import java.util.List;

import com.ruoyi.ss.wifi.domain.Wifi;
import com.ruoyi.ss.wifi.domain.WifiVO;
import com.ruoyi.ss.wifi.domain.WifiQuery;
import org.apache.ibatis.annotations.Param;

/**
 * wifiMapper接口
 *
 * @author qzz
 * @date 2025-01-06
 */
public interface WifiMapper
{
    /**
     * 查询wifi
     *
     * @param wifiId wifi主键
     * @return wifi
     */
    public WifiVO selectWifiByWifiId(Long wifiId);

    /**
     * 查询wifi列表
     *
     * @param query wifi
     * @return wifi集合
     */
    public List<WifiVO> selectWifiList(@Param("query") WifiQuery query);

    /**
     * 新增wifi
     *
     * @param wifi wifi
     * @return 结果
     */
    public int insertWifi(Wifi wifi);

    /**
     * 修改wifi
     *
     * @param wifi wifi
     * @return 结果
     */
    public int updateWifi(@Param("data") Wifi wifi);

    /**
     * 删除wifi
     *
     * @param wifiId wifi主键
     * @return 结果
     */
    public int deleteWifiByWifiId(Long wifiId);

    /**
     * 批量删除wifi
     *
     * @param wifiIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWifiByWifiIds(Long[] wifiIds);
}
